@@ -17,15 +17,15 @@ dag = DAG(
 
 fivetran_sync_start = FivetranOperator(
     task_id='fivetran-task',
-    fivetran_conn_id='fivetran',
-    connector_id=Variable.get('connector_id'),
+    fivetran_conn_id='fivetran_default',
+    connector_id="{{ var.value.get('connector_id') }}",
     dag=dag
 )
 
 fivetran_sync_wait = FivetranSensor(
     task_id='fivetran-sensor',
-    fivetran_conn_id='fivetran',
-    connector_id=Variable.get('connector_id'),
+    fivetran_conn_id='fivetran_default',
+    connector_id="{{ var.value.get('connector_id') }}",
     poke_interval=5,
     dag=dag
 )
